@@ -5,11 +5,11 @@ from __future__ import absolute_import
 from .configuration import Configuration, ConfigurationParser
 from .etl import transform, etl
 from .module import Module
-from .sym import net_viz, get_bp_loss
+from .sym import net_viz, get_loss, net_init, fit_f
 
 __all__ = [
     "Module",
     "Configuration", "ConfigurationParser",
-    "net_viz", "get_bp_loss",
+    "net_viz", "get_loss", "net_init", "fit_f",
     "etl", "transform"
 ]
