@@ -2,5 +2,4 @@
 # create by tongshiwei on 2019-8-16
 
 from .helper import pick, tensor2list
-from .util.sequence import sequence_mask
-from .toolkit.parallel import set_device
+from .toolkit import *
