@@ -5,11 +5,11 @@ from __future__ import absolute_import
 from .configuration import Configuration, ConfigurationParser
 from .etl import transform, etl
 from .module import Module
-from .sym import get_bp_loss
+from .sym import get_bp_loss, fit_f, net_init
 
 __all__ = [
     "Module",
     "Configuration", "ConfigurationParser",
     "get_bp_loss",
-    "etl", "transform"
+    "etl", "transform", "fit_f", "net_init"
 ]
