@@ -30,7 +30,7 @@ class BaseIter(object):
     """
     迭代器
 
-    Notice
+    Notes
     ------
 
     * 如果 src 是一个迭代器实例，那么在一轮迭代之后，迭代器里的内容就被迭代完了，将无法重启。
@@ -315,7 +315,7 @@ class CacheAsyncLoopIter(AsyncLoopIter):
         self.cache_queue = None
         self.cache_thread = None
 
-        if os.path.exists(self.cache_file) and not rerun:
+        if os.path.exists(self.cache_file) and rerun is False:
             # 从已有数据中进行装载
             def src():
                 return loading(self.cache_file, "jsonl")
